==> com.liferay.object.service-1.0.81-sources-commercial.jar: com/liferay/object/internal/model/listener/ObjectViewColumnModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.model.listener;

import com.liferay.object.model.ObjectViewColumn;
import com.liferay.portal.kernel.audit.AuditMessage;
import com.liferay.portal.kernel.audit.AuditRouter;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.portal.security.audit.event.generators.constants.EventTypes;
import com.liferay.portal.security.audit.event.generators.util.Attribute;
import com.liferay.portal.security.audit.event.generators.util.AttributesBuilder;
import com.liferay.portal.security.audit.event.generators.util.AuditMessageBuilder;

import java.util.List;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcela Cunha
 */
@Component(immediate = true, service = ModelListener.class)
public class ObjectViewColumnModelListener
	extends BaseModelListener<ObjectViewColumn> {

	@Override
	public void onBeforeCreate(ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		_route(EventTypes.ADD, objectViewColumn);
	}

	@Override
	public void onBeforeRemove(ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		_route(EventTypes.DELETE, objectViewColumn);
	}

	@Override
	public void onBeforeUpdate(
			ObjectViewColumn originalObjectViewColumn,
			ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		try {
			_auditRouter.route(
				AuditMessageBuilder.buildAuditMessage(
					EventTypes.UPDATE, ObjectViewColumn.class.getName(),
					objectViewColumn.getObjectViewColumnId(),
					_getModifiedAttributes(
						originalObjectViewColumn, objectViewColumn)));
		}
		catch (Exception exception) {
			throw new ModelListenerException(exception);
		}
	}

	private List<Attribute> _getModifiedAttributes(
		ObjectViewColumn originalObjectViewColumn,
		ObjectViewColumn objectViewColumn) {

		AttributesBuilder attributesBuilder = new AttributesBuilder(
			objectViewColumn, originalObjectViewColumn);

		attributesBuilder.add("labelMap");
		attributesBuilder.add("objectFieldName");
		attributesBuilder.add("priority");

		return attributesBuilder.getAttributes();
	}

	private void _route(String eventType, ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		try {
			AuditMessage auditMessage = AuditMessageBuilder.buildAuditMessage(
				eventType, ObjectViewColumn.class.getName(),
				objectViewColumn.getObjectViewColumnId(), null);

			JSONObject additionalInfoJSONObject =
				auditMessage.getAdditionalInfo();

			additionalInfoJSONObject.put(
				"labelMap", objectViewColumn.getLabelMap()
			).put(
				"objectFieldName", objectViewColumn.getObjectFieldName()
			).put(
				"priority", objectViewColumn.getPriority()
			);

			_auditRouter.route(auditMessage);
		}
		catch (Exception exception) {
			throw new ModelListenerException(exception);
		}
	}

	@Reference
	private AuditRouter _auditRouter;

}

==> com.liferay.object.service-1.0.149-sources-commercial.jar: com/liferay/object/internal/model/listener/ObjectViewColumnModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.model.listener;

import com.liferay.object.model.ObjectViewColumn;
import com.liferay.portal.kernel.audit.AuditMessage;
import com.liferay.portal.kernel.audit.AuditRouter;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.portal.security.audit.event.generators.constants.EventTypes;
import com.liferay.portal.security.audit.event.generators.util.Attribute;
import com.liferay.portal.security.audit.event.generators.util.AttributesBuilder;
import com.liferay.portal.security.audit.event.generators.util.AuditMessageBuilder;

import java.util.List;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcela Cunha
 */
@Component(service = ModelListener.class)
public class ObjectViewColumnModelListener
	extends BaseModelListener<ObjectViewColumn> {

	@Override
	public void onBeforeCreate(ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		_route(EventTypes.ADD, objectViewColumn);
	}

	@Override
	public void onBeforeRemove(ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		_route(EventTypes.DELETE, objectViewColumn);
	}

	@Override
	public void onBeforeUpdate(
			ObjectViewColumn originalObjectViewColumn,
			ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		try {
			_auditRouter.route(
				AuditMessageBuilder.buildAuditMessage(
					EventTypes.UPDATE, ObjectViewColumn.class.getName(),
					objectViewColumn.getObjectViewColumnId(),
					_getModifiedAttributes(
						originalObjectViewColumn, objectViewColumn)));
		}
		catch (Exception exception) {
			throw new ModelListenerException(exception);
		}
	}

	private List<Attribute> _getModifiedAttributes(
		ObjectViewColumn originalObjectViewColumn,
		ObjectViewColumn objectViewColumn) {

		AttributesBuilder attributesBuilder = new AttributesBuilder(
			objectViewColumn, originalObjectViewColumn);

		attributesBuilder.add("labelMap");
		attributesBuilder.add("objectFieldName");
		attributesBuilder.add("priority");

		return attributesBuilder.getAttributes();
	}

	private void _route(String eventType, ObjectViewColumn objectViewColumn)
		throws ModelListenerException {

		try {
			AuditMessage auditMessage = AuditMessageBuilder.buildAuditMessage(
				eventType, ObjectViewColumn.class.getName(),
				objectViewColumn.getObjectViewColumnId(), null);

			JSONObject additionalInfoJSONObject =
				auditMessage.getAdditionalInfo();

			additionalInfoJSONObject.put(
				"labelMap", objectViewColumn.getLabelMap()
			).put(
				"objectFieldName", objectViewColumn.getObjectFieldName()
			).put(
				"priority", objectViewColumn.getPriority()
			);

			_auditRouter.route(auditMessage);
		}
		catch (Exception exception) {
			throw new ModelListenerException(exception);
		}
	}

	@Reference
	private AuditRouter _auditRouter;

}
